@@ -5,7 +5,7 @@
 #include "timeout.h"
 #include "util/memory.h"
 
-__thread jmp_buf timeout_ptr;
+__thread sigjmp_buf timeout_ptr;
 __thread bool timeout_in = false;
 __thread timer_t *timeout_timer;
 __thread struct sigevent *sevp;
@@ -45,4 +45,4 @@ bool timeout_init() {
 void timeout_quit() {
 	// deinit the main thread.
 	timeout_thread_quit();
-}
\ No newline at end of file
+}
